extern const char **_dictionary_modemconf;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_modemconf;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_modemconf("modemconf",_dictionary_modemconf,12,0);\
	void dummy_dict_modemconf(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_modemconf[id]
	#define MSG_B(id,m,n)	_dictionary_modemconf[id]
	#define MSG_R(id)	_dictionary_modemconf[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_modemconf,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_modemconf,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_modemconf,id)
#endif
#define M_modemconf	0
#define T_USAGE	1
#define F_DEVICE	2
#define F_UNKNOWN	3
#define T_MODEMCONF	4
#define I_MODEMCONF	5
#define P_SELDEV	6
#define T_WAIT	7
#define I_PROGRESS	8
#define N_NOMODEM	9
#define N_MODEM	10
#define P_QRYDEV	11
